Documentation
¶
Index ¶
Constants ¶
const LLMInstruction = "Available: %s. Query catalog table for args schema. Example: SELECT args FROM catalog WHERE name='read';"
LLMInstruction is the prompt template for LLMs.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Parameter ¶
type Parameter struct {
Name string `json:"n"` // Name
Type string `json:"t"` // Type
Info string `json:"d"` // Description/Info
Required bool `json:"r"` // Required
}
Parameter defines an argument for a Skill. JSON tags match the compact format used in the 'catalog' view to save tokens.
type Skill ¶
type Skill struct {
Name string `json:"name"` // Matches 'name' in catalog
Category string `json:"category"` // Matches 'cat' in catalog (mapped)
Info string `json:"info"` // Matches 'info' in catalog
Parameters []Parameter `json:"parameters"` // Matches 'args' in catalog (mapped)
}
Skill represents a tool available to the LLM.
type Store ¶
type Store struct {
// contains filtered or unexported fields
}
Store provides access to the skill database.
func (*Store) GetIndex ¶
GetIndex returns a compact string representation of available skills. Format: cat1(skill1,skill2), cat2(skill3)
func (*Store) GetSchemaDescription ¶
GetSchemaDescription returns the SQL DDL commands to create the database schema.
Click to show internal directories.
Click to hide internal directories.